@@ -1,11 +1,11 @@
-# @(#)$Id: IO.pm 339 2012-03-22 13:46:07Z pjf $
+# @(#)$Id: IO.pm 342 2012-03-24 00:31:59Z pjf $
 
 package File::DataClass::IO;
 
 use strict;
 use namespace::clean -except => 'meta';
 use overload '""' => sub { shift->pathname }, fallback => 1;
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 339 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 342 $ =~ /\d+/gmx );
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -280,16 +280,18 @@ sub clear {
 }
 
 sub close {
-   my $self = shift; my $path; $self->is_open or return $self;
+   my $self = shift; $self->is_open or return $self;
 
-   if ($self->_atomic and $path = $self->_get_atomic_path and -f $path) {
-      File::Copy::move( $path, $self->name )
-         or $self->throw( error => 'Cannot rename [_1] to [_2]: [_3]',
-                          args  => [ $path, $self->name, $ERRNO ] );
+   unless ($OSNAME eq EVIL or $OSNAME eq CYGWIN) {
+      $self->_atomic and $self->_rename_atomic;
+   }
+
+   $self->unlock; $self->io_handle and $self->io_handle->close;
+
+   if ($OSNAME eq EVIL or $OSNAME eq CYGWIN) {
+      $self->_atomic and $self->_rename_atomic;
    }
 
-   $self->unlock;
-   $self->io_handle and $self->io_handle->close;
    $self->io_handle( undef );
    $self->is_open  ( FALSE );
    $self->mode     ( q(r)  );
@@ -710,6 +712,18 @@ sub relative {
    my $self = shift; $self->name( $self->abs2rel ); return $self;
 }
 
+sub _rename_atomic {
+   my $self = shift; my $path = $self->_get_atomic_path;
+
+   if ($path and -f $path) {
+      File::Copy::move( $path, $self->name )
+         or $self->throw( error => 'Cannot rename [_1] to [_2]: [_3]',
+                          args  => [ $path, $self->name, $ERRNO ] );
+   }
+
+   return;
+}
+
 sub rmdir {
    my $self = shift; return rmdir $self->name;
 }
@@ -908,7 +922,7 @@ File::DataClass::IO - Better IO syntax
 
 =head1 Version
 
-0.7.$Revision: 339 $
+0.7.$Revision: 342 $
 
 =head1 Synopsis
 
@@ -1137,12 +1151,6 @@ Set the contents of the internal buffer to the null string
 
 Close the file or directory handle depending on type
 
-=head2 _close_dir
-
-Closes the open directory handle.
-
-=head2 _close_file
-
 If the temporary atomic file exists, renames it to the original
 filename. Unlocks the file if it was locked. Closes the file handle
 
@@ -1163,7 +1171,7 @@ that the whole directory tree is searched
 =head2 delete
 
 Deletes the atomic update temporary file if it exists. Then calls
-L</_close_file>
+L</close>
 
 =head2 delete_tmp_files
 
@@ -1492,8 +1500,7 @@ Delete the specified file
 =head2 unlock
 
 Calls C<flock> on the open file handle with the I<LOCK_UN> option to
-release the L<Fcntl> lock if one was set. Called by the L</file_close>
-method
+release the L<Fcntl> lock if one was set. Called by the L</close> method
 
 =head2 utf8
 
@@ -1534,7 +1541,9 @@ None
 
 =head1 Incompatibilities
 
-There are no known incompatibilities in this module
+On MSWin32 and Cygwin platforms there is a race condition when the atomic
+write option is used. This is caused by the filesystem which does not allow
+an open file to be renamed
 
 =head1 Bugs and Limitations
 
